@@ -137,6 +137,16 @@ where
         }
     }
 
+    #[emitter]
+    fn emit_ts_member_name(&mut self, n: &TsMemberName) -> Result {
+        self.emit_leading_comments_of_span(n.span(), false)?;
+
+        match n {
+            TsMemberName::Ident(n) => emit!(n),
+            TsMemberName::PrivateName(n) => emit!(n),
+        }
+    }
+
     #[emitter]
     fn emit_ts_enum_decl(&mut self, n: &TsEnumDecl) -> Result {
         self.emit_leading_comments_of_span(n.span(), false)?;
@@ -953,6 +963,16 @@ where
     fn emit_ts_type_param(&mut self, n: &TsTypeParam) -> Result {
         self.emit_leading_comments_of_span(n.span(), false)?;
 
+        if n.is_in {
+            keyword!("in");
+            space!();
+        }
+
+        if n.is_out {
+            keyword!("out");
+            space!();
+        }
+
         emit!(n.name);
 
         if let Some(constraints) = &n.constraint {
